@@ -5,6 +5,7 @@ namespace Icinga\Protocol\Ldap;
 
 use ArrayIterator;
 use Exception;
+use Icinga\Data\Filter\FilterNot;
 use LogicException;
 use stdClass;
 use Icinga\Application\Config;
@@ -344,11 +345,10 @@ class LdapConnection implements Selectable, Inspectable
         $success = @ldap_bind($ds, $this->bindDn, $this->bindPw);
         if (! $success) {
             throw new LdapException(
-                'LDAP bind (%s / %s) to %s with default port %s failed: %s',
+                'LDAP bind (%s / %s) to %s failed: %s',
                 $this->bindDn,
                 '***' /* $this->bindPw */,
-                $this->hostname,
-                $this->port,
+                $this->normalizeHostname($this->hostname),
                 ldap_error($ds)
             );
         }
@@ -1179,22 +1179,7 @@ class LdapConnection implements Selectable, Inspectable
             $info = new Inspection('');
         }
 
-        $hostname = $this->hostname;
-        if ($this->encryption === static::LDAPS) {
-            $info->write('Connect using LDAPS');
-            $ldapUrls = explode(' ', $hostname);
-            if (count($ldapUrls) > 1) {
-                foreach ($ldapUrls as & $uri) {
-                    if (strpos($uri, '://') === false) {
-                        $uri = 'ldaps://' . $uri;
-                    }
-                }
-
-                $hostname = implode(' ', $ldapUrls);
-            } else {
-                $hostname = 'ldaps://' . $hostname;
-            }
-        }
+        $hostname = $this->normalizeHostname($this->hostname);
 
         $ds = ldap_connect($hostname, $this->port);
 
@@ -1209,7 +1194,9 @@ class LdapConnection implements Selectable, Inspectable
         // Not setting this results in "Operations error" on AD when using the whole domain as search base
         ldap_set_option($ds, LDAP_OPT_REFERRALS, 0);
 
-        if ($this->encryption === static::STARTTLS) {
+        if ($this->encryption === static::LDAPS) {
+            $info->write('Connect using LDAPS');
+        } elseif ($this->encryption === static::STARTTLS) {
             $this->encrypted = true;
             $info->write('Connect using STARTTLS');
             if (! ldap_start_tls($ds)) {
@@ -1253,23 +1240,6 @@ class LdapConnection implements Selectable, Inspectable
             // We're checking the level by ourselves to avoid rendering the ldapsearch commandline for nothing
             $starttlsParam = $this->encryption === static::STARTTLS ? ' -ZZ' : '';
 
-            $ldapUrls = array();
-            $defaultScheme = $this->encryption === static::LDAPS ? 'ldaps://' : 'ldap://';
-            foreach (explode(' ', $this->hostname) as $uri) {
-                $url = Url::fromPath($uri);
-                if (! $url->getScheme()) {
-                    $uri = $defaultScheme . $uri . ($this->port ? ':' . $this->port : '');
-                } else {
-                    if ($url->getPort() === null) {
-                        $url->setPort($this->port);
-                    }
-
-                    $uri = $url->getAbsoluteUrl();
-                }
-
-                $ldapUrls[] = $uri;
-            }
-
             $bindParams = '';
             if ($this->bound) {
                 $bindParams = ' -D "' . $this->bindDn . '"' . ($this->bindPw ? ' -W' : '');
@@ -1285,10 +1255,10 @@ class LdapConnection implements Selectable, Inspectable
                 $derefName = 'find';
             }
 
-            Logger::debug("Issueing LDAP search. Use '%s' to reproduce.", sprintf(
+            Logger::debug("Issuing LDAP search. Use '%s' to reproduce.", sprintf(
                 'ldapsearch -P 3%s -H "%s"%s -b "%s" -s "%s" -z %u -l %u -a "%s"%s%s%s',
                 $starttlsParam,
-                implode(' ', $ldapUrls),
+                $this->normalizeHostname($this->hostname),
                 $bindParams,
                 $baseDn,
                 $scope,
@@ -1421,7 +1391,7 @@ class LdapConnection implements Selectable, Inspectable
         }
 
         $format = '%1$s(%2$s)';
-        if (count($parts) === 1) {
+        if (count($parts) === 1 && ! $filter instanceof FilterNot) {
             $format = '%2$s';
         }
         if ($level === 0) {
@@ -1508,11 +1478,10 @@ class LdapConnection implements Selectable, Inspectable
         // Try a bind-command with the given user credentials, this must not fail
         $success = @ldap_bind($ds, $this->bindDn, $this->bindPw);
         $msg = sprintf(
-            'LDAP bind (%s / %s) to %s with default port %s',
+            'LDAP bind (%s / %s) to %s',
             $this->bindDn,
             '***' /* $this->bindPw */,
-            $this->hostname,
-            $this->port
+            $this->normalizeHostname($this->hostname)
         );
         if (! $success) {
             // ldap_error does not return any proper error messages in case of certificate errors. Connecting
@@ -1543,4 +1512,33 @@ class LdapConnection implements Selectable, Inspectable
         }
         return $insp;
     }
+
+    protected function normalizeHostname($hostname)
+    {
+        $scheme = $this->encryption === static::LDAPS ? 'ldaps://' : 'ldap://';
+        $normalizeHostname = function ($hostname) use ($scheme) {
+            if (strpos($hostname, $scheme) === false) {
+                $hostname = $scheme . $hostname;
+            }
+
+            if (! preg_match('/:\d+$/', $hostname)) {
+                $hostname .= ':' . $this->port;
+            }
+
+            return $hostname;
+        };
+
+        $ldapUrls = explode(' ', $hostname);
+        if (count($ldapUrls) > 1) {
+            foreach ($ldapUrls as & $uri) {
+                $uri = $normalizeHostname($uri);
+            }
+
+            $hostname = implode(' ', $ldapUrls);
+        } else {
+            $hostname = $normalizeHostname($hostname);
+        }
+
+        return $hostname;
+    }
 }
