@@ -3,6 +3,7 @@
 
 namespace Icinga\Web;
 
+use Icinga\Web\Form\Element\DateTimePicker;
 use Zend_Config;
 use Zend_Form;
 use Zend_Form_Element;
@@ -31,6 +32,11 @@ class Form extends Zend_Form
      */
     const DEFAULT_SUFFIX = '_default';
 
+    /**
+     * A form's default CSS classes
+     */
+    const DEFAULT_CLASSES = 'icinga-form icinga-controls';
+
     /**
      * Identifier for notifications of type error
      */
@@ -210,9 +216,9 @@ class Form extends Zend_Form
      */
     public static $defaultElementDecorators = array(
         array('Label', array('tag'=>'span', 'separator' => '', 'class' => 'control-label')),
-        array('Help', array('placement' => 'APPEND')),
         array(array('labelWrap' => 'HtmlTag'), array('tag' => 'div', 'class' => 'control-label-group')),
         array('ViewHelper', array('separator' => '')),
+        array('Help', array()),
         array('Errors', array('separator' => '')),
         array('HtmlTag', array('tag' => 'div', 'class' => 'control-group'))
     );
@@ -238,6 +244,10 @@ class Form extends Zend_Form
             )
         ));
 
+        if (! isset($options['attribs']['class'])) {
+            $options['attribs']['class'] = static::DEFAULT_CLASSES;
+        }
+
         parent::__construct($options);
     }
 
@@ -833,6 +843,7 @@ class Form extends Zend_Form
                 'submit',
                 'btn_submit',
                 array(
+                    'class'                 => 'btn-primary',
                     'ignore'                => true,
                     'label'                 => $submitLabel,
                     'data-progress-label'   => $this->getProgressLabel(),
@@ -983,7 +994,9 @@ class Form extends Zend_Form
                     'tag'   => 'input',
                     'type'  => 'hidden',
                     'name'  => $name . static::DEFAULT_SUFFIX,
-                    'value' => $el->getValue()
+                    'value' => $el instanceof DateTimePicker
+                        ? $el->getValue()->format($el->getFormat())
+                        : $el->getValue()
                 )
             );
 
@@ -1143,7 +1156,11 @@ class Form extends Zend_Form
         }
 
         $formData = $this->getRequestData();
-        if ($this->getIsApiTarget() || $this->getUidDisabled() || $this->wasSent($formData)) {
+        if ($this->getIsApiTarget()
+            || $this->getRequest()->isApiRequest()
+            || $this->getUidDisabled()
+            || $this->wasSent($formData)
+        ) {
             if (($frameUpload = (bool) $request->getUrl()->shift('_frameUpload', false))) {
                 $this->getView()->layout()->setLayout('wrapped');
             }
@@ -1172,7 +1189,7 @@ class Form extends Zend_Form
                     } else {
                         $this->getView()->layout()->redirectUrl = $this->getRedirectUrl()->getAbsoluteUrl();
                     }
-                } elseif ($this->getIsApiTarget()) {
+                } elseif ($this->getIsApiTarget() || $this->getRequest()->isApiRequest()) {
                     $this->getResponse()->json()->setFailData($this->getMessages())->sendResponse();
                 }
             } elseif ($this->getValidatePartial()) {
@@ -1198,7 +1215,7 @@ class Form extends Zend_Form
         if (strtolower($this->getRequest()->getMethod()) !== $this->getMethod()) {
             return false;
         }
-        if ($this->getIsApiTarget()) {
+        if ($this->getIsApiTarget() || $this->getRequest()->isApiRequest()) {
             return true;
         }
         if ($this->getSubmitLabel()) {
